import knex from '../../../db/knex_router';
import * as connectors from '../connectors/connectors';
import * as authentifiers from '../connectors/authentifiers';

const GroupResolvers = {
    // @rights viewer(obj.uid)
    Group: {
        __resolveType: async (obj) => {

            switch (obj.type) {
            case "simple":
                return "SimpleGroup";
            case "meta":
                return "MetaGroup";
            }
        }
    },


    // @rights viewer(obj.uid)
    SimpleGroup: {

        admins: async function (obj, args, context) {
            let user = await authentifiers.member(context.user, obj.uid);
            return await user.ldap_access.listMembers(context.user, obj.uid);
        },

        members: async function (obj, args, context) {
            let user = await authentifiers.member(context.user, obj.uid);
            return user.ldap_access.listMembers(context.user, obj.uid);
        },

        likers: async function (obj, args, context) {
            return connectors.utilisateur.listMembers(context.user, obj.uid);
        },

        privatePosts: async function (obj, args, context) {
            let user = await authentifiers.member(context.user, obj.uid);
            return user && connectors.receivedPrivatePosts(user, obj.uid);
        },

        questions: async function (obj, args, context) {
            let user = await authentifiers.member(context.user, obj.uid);
            return user && connectors.receivedQuestions(user, obj.uid);
        },

        answers: async function (obj, args, context) {
            let user = await authentifiers.member(context.user, obj.uid);
            return user && connectors.receivedAnswers(user, obj.uid);
        }
    },

    // @rights viewer(obj.uid)
    MetaGroup: {
        members: (obj, args, context) => {
        },

        privatePosts: async function (obj, args, context) {
            let user = await authentifiers.member(context.user, obj.uid);
            return user && connectors.receivedPrivatePosts(user, obj.uid);
        },

        questions: async function (obj, args, context) {
            let user = await authentifiers.member(context.user, obj.uid);
            return user && connectors.receivedQuestions(user, obj.uid);
        },

        answers: async function (obj, args, context) {
            let user = await authentifiers.member(context.user, obj.uid);
            return user && connectors.receivedAnswers(user, obj.uid);
        }
    }
};

export default GroupResolvers;